@@ -93,9 +93,8 @@ public class LafWidgetSupport {
 	 * 
 	 * @param comp
 	 *            Component.
-	 * @return <code>true</code> if additional functionality should be
-	 *         installed on the specified component, <code>false</code>
-	 *         otherwise.
+	 * @return <code>true</code> if additional functionality should be installed
+	 *         on the specified component, <code>false</code> otherwise.
 	 */
 	public boolean toInstallExtraElements(Component comp) {
 		return true;
@@ -193,6 +192,7 @@ public class LafWidgetSupport {
 	 *             In the base implementation.
 	 */
 	public void setTabAreaInsets(JTabbedPane tabbedPane, Insets tabAreaInsets) {
+		Insets old = this.getTabAreaInsets(tabbedPane);
 		TabbedPaneUI ui = tabbedPane.getUI();
 		if (ui instanceof BasicTabbedPaneUI) {
 			try {
@@ -203,6 +203,11 @@ public class LafWidgetSupport {
 						if (fld != null) {
 							fld.setAccessible(true);
 							fld.set(ui, tabAreaInsets);
+							// Fire a property change event so that the tabbed
+							// pane can revalidate itself
+							LafWidgetUtilities.firePropertyChangeEvent(
+									tabbedPane, "tabAreaInsets", old,
+									tabAreaInsets);
 							return;
 						}
 					} catch (NoSuchFieldException nsfe) {
