@@ -32,6 +32,8 @@ package org.jvnet.lafwidget;
 import java.awt.*;
 import java.awt.geom.GeneralPath;
 import java.awt.image.BufferedImage;
+import java.beans.PropertyChangeEvent;
+import java.beans.PropertyChangeListener;
 import java.util.*;
 
 import javax.swing.*;
@@ -64,9 +66,9 @@ public class LafWidgetUtilities {
 	 * Retrieves transparent image of specified dimension.
 	 * 
 	 * @param width
-	 * 		Image width.
+	 *            Image width.
 	 * @param height
-	 * 		Image height.
+	 *            Image height.
 	 * @return Transparent image of specified dimension.
 	 */
 	public static BufferedImage getBlankImage(int width, int height) {
@@ -87,7 +89,7 @@ public class LafWidgetUtilities {
 	 * Creates a compatible image (for efficient processing and drawing).
 	 * 
 	 * @param image
-	 * 		The original image.
+	 *            The original image.
 	 * @return Compatible version of the original image.
 	 * @author Romain Guy
 	 */
@@ -108,9 +110,9 @@ public class LafWidgetUtilities {
 	 * Creates a thumbnail of the specified width.
 	 * 
 	 * @param image
-	 * 		The original image.
+	 *            The original image.
 	 * @param requestedThumbWidth
-	 * 		The width of the resulting thumbnail.
+	 *            The width of the resulting thumbnail.
 	 * @return Thumbnail of the specified width.
 	 * @author Romain Guy
 	 */
@@ -144,9 +146,9 @@ public class LafWidgetUtilities {
 	 * Returns search icon.
 	 * 
 	 * @param dimension
-	 * 		Icon dimension.
+	 *            Icon dimension.
 	 * @param leftToRight
-	 * 		Indicates the orientation of the resulting icon.
+	 *            Indicates the orientation of the resulting icon.
 	 * @return Search icon.
 	 */
 	public static Icon getSearchIcon(int dimension, boolean leftToRight) {
@@ -198,7 +200,7 @@ public class LafWidgetUtilities {
 	 * arranged in 2*2 grid.
 	 * 
 	 * @param value
-	 * 		Integer value to represent.
+	 *            Integer value to represent.
 	 * @return Icon representation of the specified integer value.
 	 */
 	public static Icon getHexaMarker(int value) {
@@ -234,11 +236,12 @@ public class LafWidgetUtilities {
 	 * Makes the specified component and all its descendants previewable.
 	 * 
 	 * @param comp
-	 * 		Component.
+	 *            Component.
 	 * @param dbSnapshot
-	 * 		The "snapshot" map that will contain the original double-buffer
-	 * 		status of the specified component and all its descendants. Key is
-	 * 		{@link JComponent}, value is {@link Boolean}.
+	 *            The "snapshot" map that will contain the original
+	 *            double-buffer status of the specified component and all its
+	 *            descendants. Key is {@link JComponent}, value is
+	 *            {@link Boolean}.
 	 */
 	public static void makePreviewable(Component comp,
 			Map<Component, Boolean> dbSnapshot) {
@@ -266,11 +269,11 @@ public class LafWidgetUtilities {
 	 * and all its descendants.
 	 * 
 	 * @param comp
-	 * 		Component.
+	 *            Component.
 	 * @param dbSnapshot
-	 * 		The "snapshot" map that contains the original double-buffer status
-	 * 		of the specified component and all its descendants. Key is {@link
-	 * 		JComponent}, value is {@link Boolean}.
+	 *            The "snapshot" map that contains the original double-buffer
+	 *            status of the specified component and all its descendants. Key
+	 *            is {@link JComponent}, value is {@link Boolean}.
 	 */
 	public static void restorePreviewable(Component comp,
 			Map<Component, Boolean> dbSnapshot) {
@@ -309,7 +312,7 @@ public class LafWidgetUtilities {
 	 * Returns the animation kind of the specified component.
 	 * 
 	 * @param component
-	 * 		Component.
+	 *            Component.
 	 * @return The animation kind of the specified component.
 	 */
 	public static AnimationKind getAnimationKind(Component component) {
@@ -377,9 +380,9 @@ public class LafWidgetUtilities {
 	 * "select all on focus gain" property.
 	 * 
 	 * @param textComp
-	 * 		Text component.
+	 *            Text component.
 	 * @return <code>true</code> if the specified text component has "select all
-	 * 	on focus gain" property, <code>false</code> otherwise.
+	 *         on focus gain" property, <code>false</code> otherwise.
 	 */
 	public static boolean hasTextFocusSelectAllProperty(JTextComponent textComp) {
 		Component comp = textComp;
@@ -403,9 +406,9 @@ public class LafWidgetUtilities {
 	 * property.
 	 * 
 	 * @param textComp
-	 * 		Text component.
+	 *            Text component.
 	 * @return <code>true</code> if the specified text component has "flip
-	 * 	select on escape" property, <code>false</code> otherwise.
+	 *         select on escape" property, <code>false</code> otherwise.
 	 */
 	public static boolean hasTextFlipSelectOnEscapeProperty(
 			JTextComponent textComp) {
@@ -424,9 +427,9 @@ public class LafWidgetUtilities {
 	 * property.
 	 * 
 	 * @param textComp
-	 * 		Text component.
+	 *            Text component.
 	 * @return <code>true</code> if the specified text component has edit
-	 * 	context menu property, <code>false</code> otherwise.
+	 *         context menu property, <code>false</code> otherwise.
 	 */
 	public static boolean hasTextEditContextMenu(JTextComponent textComp) {
 		Object textEditContextMenuProperty = textComp
@@ -443,9 +446,9 @@ public class LafWidgetUtilities {
 	 * Checks whether the specified scroll pane supports auto scroll.
 	 * 
 	 * @param scrollPane
-	 * 		Scroll pane component.
+	 *            Scroll pane component.
 	 * @return <code>true</code> if the specified scroll pane supports auto
-	 * 	scroll, <code>false</code> otherwise.
+	 *         scroll, <code>false</code> otherwise.
 	 */
 	public static boolean hasAutoScroll(JScrollPane scrollPane) {
 		Object compProperty = scrollPane
@@ -462,9 +465,9 @@ public class LafWidgetUtilities {
 	 * support.
 	 * 
 	 * @param tree
-	 * 		Tree component.
+	 *            Tree component.
 	 * @return <code>true</code> if the specified text component has automatic
-	 * 	drag and drop support, <code>false</code> otherwise.
+	 *         drag and drop support, <code>false</code> otherwise.
 	 */
 	public static boolean hasAutomaticDnDSupport(JTree tree) {
 		Object dndProperty = tree
@@ -482,11 +485,12 @@ public class LafWidgetUtilities {
 	 * the specified component.
 	 * 
 	 * @param jcomp
-	 * 		Component.
+	 *            Component.
 	 * @return <code>true</code> if the custom labels should be looked up based
-	 * 	on the component locale as returned by {@link JComponent#getLocale()},
-	 * 	<code>false</code> if the custom labels should be looked up based on the
-	 * 	global locale as returned by {@link Locale#getDefault()}.
+	 *         on the component locale as returned by
+	 *         {@link JComponent#getLocale()}, <code>false</code> if the custom
+	 *         labels should be looked up based on the global locale as returned
+	 *         by {@link Locale#getDefault()}.
 	 */
 	public static boolean toIgnoreGlobalLocale(JComponent jcomp) {
 		if (jcomp == null)
@@ -499,7 +503,7 @@ public class LafWidgetUtilities {
 	 * Returns the resource bundle for the specified component.
 	 * 
 	 * @param jcomp
-	 * 		Component.
+	 *            Component.
 	 * @return Resource bundle for the specified component.
 	 */
 	public static ResourceBundle getResourceBundle(JComponent jcomp) {
@@ -516,11 +520,11 @@ public class LafWidgetUtilities {
 	 * large tables and lists.
 	 * 
 	 * @param comp
-	 * 		Component.
+	 *            Component.
 	 * @param fadeKind
-	 * 		Fade kind.
+	 *            Fade kind.
 	 * @return <code>true</code> if the specified fade kind has no animations on
-	 * 	the specified component, <code>false</code> otherwise.
+	 *         the specified component, <code>false</code> otherwise.
 	 */
 	public static boolean hasNoFades(Component comp, FadeKind fadeKind) {
 		return (LafWidgetUtilities.getAnimationKind(comp) == AnimationKind.NONE)
@@ -533,7 +537,7 @@ public class LafWidgetUtilities {
 	 * internal use only</b>.
 	 * 
 	 * @param b
-	 * 		Button.
+	 *            Button.
 	 * @return Icon for the specified button.
 	 */
 	public static Icon getIcon(AbstractButton b) {
@@ -592,4 +596,30 @@ public class LafWidgetUtilities {
 			throw uiThreadingViolationError;
 		}
 	}
+
+	/**
+	 * Fires the matching property change event on the specific component.
+	 * 
+	 * @param component
+	 *            Component.
+	 * @param propertyName
+	 *            Property name.
+	 * @param oldValue
+	 *            Old property value.
+	 * @param newValue
+	 *            New property value.
+	 */
+	public static void firePropertyChangeEvent(JComponent component,
+			String propertyName, Object oldValue, Object newValue) {
+		PropertyChangeEvent pce = new PropertyChangeEvent(component,
+				propertyName, oldValue, newValue);
+		for (PropertyChangeListener general : component
+				.getPropertyChangeListeners()) {
+			general.propertyChange(pce);
+		}
+		for (PropertyChangeListener specific : component
+				.getPropertyChangeListeners(propertyName)) {
+			specific.propertyChange(pce);
+		}
+	}
 }
