@@ -409,6 +409,13 @@ public class FadeTracker {
 					} else {
 						compId.component.repaint();
 					}
+				} else {
+					if (state.fadeKind == FadeKind.GHOSTING_BUTTON_PRESS) {
+						this.callbackCallFadeEnded(state.getCallback(),
+								state.fadeKind);
+						this.globalCallbackCallFadeEnded(compId.component,
+								compId.subID, state.fadeKind);
+					}
 				}
 			}
 			// if (mapComp.size() == 0)
