@@ -74,9 +74,9 @@ public class GhostingListener {
 	 * transitions.
 	 * 
 	 * @param comp
-	 * 		Component.
+	 *            Component.
 	 * @param buttonModel
-	 * 		Model for the component.
+	 *            Model for the component.
 	 */
 	public GhostingListener(Component comp, ButtonModel buttonModel) {
 		this.comp = comp;
@@ -93,9 +93,9 @@ public class GhostingListener {
 	 * Tracks a single change to the model.
 	 * 
 	 * @param fadeKind
-	 * 		Fade animation kind.
+	 *            Fade animation kind.
 	 * @param newState
-	 * 		New value of the relevant attribute of the model.
+	 *            New value of the relevant attribute of the model.
 	 */
 	protected void trackModelChange(FadeKind fadeKind, boolean newState) {
 		if (LafWidgetUtilities.toIgnoreAnimations(this.comp))
@@ -106,13 +106,42 @@ public class GhostingListener {
 				if (!prevState && newState) {
 					FadeTracker.getInstance().trackFadeIn(fadeKind, this.comp,
 							null, false, new UIThreadFadeTrackerAdapter() {
+								private boolean wasShowing = true;
+
 								protected void repaintTopLevelWindows(
 										float fadeCycle) {
 									if (comp == null)
 										return;
 
-									if (!comp.isShowing())
+									boolean isShowing = comp.isShowing();
+									if (isShowing) {
+										Window compWindow = SwingUtilities
+												.getWindowAncestor(comp);
+										if (!compWindow.isDisplayable()
+												|| !compWindow.isShowing()
+												|| !compWindow.isVisible()) {
+											isShowing = false;
+										}
+									}
+
+									if (!isShowing) {
+										if (wasShowing) {
+											// need to repaint all other windows
+											// once - otherwise we will see
+											// painting artifacts from
+											// a pressed button that was made
+											// invisible
+											for (Window w : Window.getWindows()) {
+												if (w.isDisplayable()
+														&& w.isVisible()
+														&& w.isShowing()) {
+													w.repaint();
+												}
+											}
+										}
+										wasShowing = false;
 										return;
+									}
 									Component root = SwingUtilities
 											.getRoot(comp);
 									Rectangle compRect = comp.getBounds();
@@ -149,13 +178,11 @@ public class GhostingListener {
 									for (Window w : Window.getWindows()) {
 										if (w == root)
 											continue;
-										// String title = (w instanceof Frame) ?
-										// ((Frame) w)
-										// .getTitle()
-										// : (w instanceof Dialog) ? ((Dialog) w
-										// )
-										// .getTitle()
-										// : null;
+										String title = (w instanceof Frame) ? ((Frame) w)
+												.getTitle()
+												: (w instanceof Dialog) ? ((Dialog) w)
+														.getTitle()
+														: null;
 										// System.out.println(title + ":"
 										// + w.isDisplayable() + ":"
 										// + w.isVisible());
@@ -177,7 +204,7 @@ public class GhostingListener {
 																.getLocationOnScreen().y;
 												// System.out
 												// .println("Repainting "
-												// + fadeCycle10
+												// + fadeCycle
 												// + ":"
 												// + title
 												// + " at "
