@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2005-2008 Laf-Widget Kirill Grouchnikov. All Rights Reserved.
+ * Copyright (c) 2005-2009 Laf-Widget Kirill Grouchnikov. All Rights Reserved.
  *
  * Redistribution and use in source and binary forms, with or without 
  * modification, are permitted provided that the following conditions are met:
@@ -31,6 +31,7 @@ package org.jvnet.lafwidget.ant;
 
 import java.io.*;
 import java.lang.reflect.Method;
+import java.lang.reflect.Modifier;
 import java.net.URL;
 import java.net.URLClassLoader;
 import java.util.*;
@@ -90,14 +91,14 @@ public class UiDelegateAugmenter {
 		 * Creates a new augmentor.
 		 * 
 		 * @param cv
-		 * 		Class visitor to recreate the non-augmented methods.
+		 *            Class visitor to recreate the non-augmented methods.
 		 * @param existingMethods
-		 * 		Contains all method names.
+		 *            Contains all method names.
 		 * @param existingFields
-		 * 		Contains all field names.
+		 *            Contains all field names.
 		 * @param methodsToAugment
-		 * 		Contains all methods that will be augmented. Key is {@link
-		 * 		String}, value is {@link Method}.
+		 *            Contains all methods that will be augmented. Key is
+		 *            {@link String}, value is {@link Method}.
 		 */
 		public AugmentClassAdapter(final ClassVisitor cv,
 				Set<String> existingMethods, Set<String> existingFields,
@@ -176,11 +177,12 @@ public class UiDelegateAugmenter {
 					} else {
 						if (method.getParameterTypes().length == 0) {
 							this.augmentVoidMethod(!hasOriginal, name,
-									superName, methodName);
+									superName, methodName, method
+											.getModifiers());
 						} else {
 							this.augmentSingleParameterMethod(!hasOriginal,
-									name, superName, methodName,
-									methodSignature);
+									name, superName, methodName, method
+											.getModifiers(), methodSignature);
 						}
 					}
 				}
@@ -191,21 +193,27 @@ public class UiDelegateAugmenter {
 		 * Augments void UI method (w/o parameters).
 		 * 
 		 * @param toSynthOriginal
-		 * 		Indication whether we need to create an empty (only call to
-		 * 		super()) implementation.
+		 *            Indication whether we need to create an empty (only call
+		 *            to super()) implementation.
 		 * @param className
-		 * 		Class name.
+		 *            Class name.
 		 * @param superClassName
-		 * 		Super class name (relevant for generating empty implementation).
+		 *            Super class name (relevant for generating empty
+		 *            implementation).
 		 * @param methodName
-		 * 		Method name.
+		 *            Method name.
 		 */
 		public void augmentVoidMethod(boolean toSynthOriginal,
-				String className, String superClassName, String methodName) {
+				String className, String superClassName, String methodName,
+				int methodModifiers) {
+			int modifierOpcode = Opcodes.ACC_PUBLIC;
+			if (Modifier.isProtected(methodModifiers))
+				modifierOpcode = Opcodes.ACC_PROTECTED;
+
 			// Some ASM woodoo. The code below was generated by using
 			// ASMifierClassVisitor.
 			if (toSynthOriginal) {
-				MethodVisitor mv = this.cv.visitMethod(Opcodes.ACC_PUBLIC,
+				MethodVisitor mv = this.cv.visitMethod(modifierOpcode,
 						this.prefix + methodName, "()V", null, null);
 				mv.visitCode();
 				mv.visitVarInsn(Opcodes.ALOAD, 0);
@@ -216,8 +224,8 @@ public class UiDelegateAugmenter {
 				mv.visitEnd();
 			}
 
-			MethodVisitor mv = this.cv.visitMethod(Opcodes.ACC_PUBLIC,
-					methodName, "()V", null, null);
+			MethodVisitor mv = this.cv.visitMethod(modifierOpcode, methodName,
+					"()V", null, null);
 			mv.visitCode();
 			mv.visitVarInsn(Opcodes.ALOAD, 0);
 			mv.visitMethodInsn(Opcodes.INVOKEVIRTUAL, className, this.prefix
@@ -256,22 +264,28 @@ public class UiDelegateAugmenter {
 		 * Augments single-parameter UI method.
 		 * 
 		 * @param toSynthOriginal
-		 * 		Indication whether we need to create an empty (only call to
-		 * 		super()) implementation.
+		 *            Indication whether we need to create an empty (only call
+		 *            to super()) implementation.
 		 * @param className
-		 * 		Class name.
+		 *            Class name.
 		 * @param superClassName
-		 * 		Super class name (relevant for generating empty implementation).
+		 *            Super class name (relevant for generating empty
+		 *            implementation).
 		 * @param methodName
-		 * 		Method name.
+		 *            Method name.
 		 * @param functionDesc
-		 * 		Function signature (using JNI style declaration). Example for
-		 * 		<code>void installUI(JButton button)</code>:
-		 * 		<code>(Ljavax/swing/JButton;)V</code>.
+		 *            Function signature (using JNI style declaration). Example
+		 *            for <code>void installUI(JButton button)</code>:
+		 *            <code>(Ljavax/swing/JButton;)V</code>.
 		 */
 		public void augmentSingleParameterMethod(boolean toSynthOriginal,
 				String className, String superClassName, String methodName,
-				String functionDesc) {
+				int methodModifiers, String functionDesc) {
+
+			int modifierOpcode = Opcodes.ACC_PUBLIC;
+			if (Modifier.isProtected(methodModifiers))
+				modifierOpcode = Opcodes.ACC_PROTECTED;
+
 			// Some ASM woodoo. The code below was generated by using
 			// ASMifierClassVisitor.
 			if (toSynthOriginal) {
@@ -280,7 +294,7 @@ public class UiDelegateAugmenter {
 							+ functionDesc + "' forwarding to super '"
 							+ superClassName + "'");
 				}
-				MethodVisitor mv = this.cv.visitMethod(Opcodes.ACC_PUBLIC,
+				MethodVisitor mv = this.cv.visitMethod(modifierOpcode,
 						this.prefix + methodName, functionDesc, null, null);
 				mv.visitCode();
 				mv.visitVarInsn(Opcodes.ALOAD, 0);
@@ -296,8 +310,8 @@ public class UiDelegateAugmenter {
 				System.out.println("... Augmenting '" + methodName
 						+ functionDesc + "'");
 			}
-			MethodVisitor mv = this.cv.visitMethod(Opcodes.ACC_PUBLIC,
-					methodName, functionDesc, null, null);
+			MethodVisitor mv = this.cv.visitMethod(modifierOpcode, methodName,
+					functionDesc, null, null);
 			mv.visitCode();
 			mv.visitVarInsn(Opcodes.ALOAD, 0);
 			mv.visitVarInsn(Opcodes.ALOAD, 1);
@@ -338,16 +352,17 @@ public class UiDelegateAugmenter {
 		 * have a single parameter.
 		 * 
 		 * @param toSynthOriginal
-		 * 		Indication whether we need to create an empty (only call to
-		 * 		super()) implementation.
+		 *            Indication whether we need to create an empty (only call
+		 *            to super()) implementation.
 		 * @param className
-		 * 		Class name.
+		 *            Class name.
 		 * @param superClassName
-		 * 		Super class name (relevant for generating empty implementation).
+		 *            Super class name (relevant for generating empty
+		 *            implementation).
 		 * @param functionDesc
-		 * 		Function signature (using JNI style declaration). Example for
-		 * 		<code>void installUI(JButton button)</code>:
-		 * 		<code>(Ljavax/swing/JButton;)V</code>.
+		 *            Function signature (using JNI style declaration). Example
+		 *            for <code>void installUI(JButton button)</code>:
+		 *            <code>(Ljavax/swing/JButton;)V</code>.
 		 */
 		public void augmentInstallUIMethod(boolean toSynthOriginal,
 				String className, String superClassName, String functionDesc) {
@@ -420,16 +435,17 @@ public class UiDelegateAugmenter {
 		 * have two parameters.
 		 * 
 		 * @param toSynthOriginal
-		 * 		Indication whether we need to create an empty (only call to
-		 * 		super()) implementation.
+		 *            Indication whether we need to create an empty (only call
+		 *            to super()) implementation.
 		 * @param className
-		 * 		Class name.
+		 *            Class name.
 		 * @param superClassName
-		 * 		Super class name (relevant for generating empty implementation).
+		 *            Super class name (relevant for generating empty
+		 *            implementation).
 		 * @param functionDesc
-		 * 		Function signature (using JNI style declaration). Example for
-		 * 		<code>void installUI(JButton button)</code>:
-		 * 		<code>(Ljavax/swing/JButton;)V</code>.
+		 *            Function signature (using JNI style declaration). Example
+		 *            for <code>void installUI(JButton button)</code>:
+		 *            <code>(Ljavax/swing/JButton;)V</code>.
 		 */
 		public void augmentUpdateMethod(boolean toSynthOriginal,
 				String className, String superClassName, String functionDesc) {
@@ -623,11 +639,11 @@ public class UiDelegateAugmenter {
 	 * Augments a single class with additional UI behaviour.
 	 * 
 	 * @param dir
-	 * 		Root directory for the library that contains the class.
+	 *            Root directory for the library that contains the class.
 	 * @param name
-	 * 		Fully-qualified class name.
+	 *            Fully-qualified class name.
 	 * @throws AugmentException
-	 * 		If the augmentation process failed.
+	 *             If the augmentation process failed.
 	 */
 	protected synchronized void augmentClass(String dir, final String name) {
 		if (this.isVerbose)
@@ -669,7 +685,17 @@ public class UiDelegateAugmenter {
 										.isAssignableFrom(paramTypes[0])))
 								|| ("update".equals(method.getName()) && (paramTypes.length == 2));
 						if (isSupportedRetType && isSupportedParamList)
-							methodsToAugment.put(method.getName(), method);
+							if (Modifier.isProtected(method.getModifiers())
+									|| Modifier.isPublic(method.getModifiers())) {
+								methodsToAugment.put(method.getName(), method);
+							} else {
+								if (isVerbose) {
+									System.out
+											.println("Not augmenting private "
+													+ name + "."
+													+ method.getName());
+								}
+							}
 						else
 							throw new AugmentException("Method '"
 									+ method.getName() + "' in class '" + name
@@ -768,15 +794,16 @@ public class UiDelegateAugmenter {
 	 * Processes a single file or a directory, augmenting all relevant classes.
 	 * 
 	 * @param toStrip
-	 * 		The leading prefix to strip from the file names. Is used to create
-	 * 		fully-qualified class name.
+	 *            The leading prefix to strip from the file names. Is used to
+	 *            create fully-qualified class name.
 	 * @param file
-	 * 		File resource (can point to a single file or to a directory).
+	 *            File resource (can point to a single file or to a directory).
 	 * @param pattern
-	 * 		Pattern to apply to the file name (of the single file). If the file
-	 * 		name matches the pattern, the relevant class is augmented.
+	 *            Pattern to apply to the file name (of the single file). If the
+	 *            file name matches the pattern, the relevant class is
+	 *            augmented.
 	 * @throws AugmentException
-	 * 		If the augmentation process failed.
+	 *             If the augmentation process failed.
 	 */
 	public void process(String toStrip, File file, Pattern pattern)
 			throws AugmentException {
@@ -801,7 +828,7 @@ public class UiDelegateAugmenter {
 	 * Sets the verbosity.
 	 * 
 	 * @param isVerbose
-	 * 		New value for augmentation process verbosity.
+	 *            New value for augmentation process verbosity.
 	 */
 	public void setVerbose(boolean isVerbose) {
 		this.isVerbose = isVerbose;
