@@ -30,6 +30,7 @@
 package org.jvnet.lafwidget.tabbed;
 
 import java.awt.Insets;
+import java.awt.event.*;
 import java.beans.PropertyChangeEvent;
 import java.beans.PropertyChangeListener;
 
@@ -53,6 +54,11 @@ public class TabOverviewDialogWidget extends LafWidgetAdapter<JTabbedPane> {
 	 */
 	protected PropertyChangeListener propertyListener;
 
+	/**
+	 * Listens on tabs being added or removed.
+	 */
+	protected ContainerListener containerListener;
+
 	/*
 	 * (non-Javadoc)
 	 * 
@@ -158,19 +164,9 @@ public class TabOverviewDialogWidget extends LafWidgetAdapter<JTabbedPane> {
 								.remove(TabOverviewDialogWidget.this.overviewButton);
 					}
 				}
-				if ("tabPlacement".equals(evt.getPropertyName())) {
-					SwingUtilities.invokeLater(new Runnable() {
-						public void run() {
-							if (TabOverviewDialogWidget.this.overviewButton
-									.getParent() == TabOverviewDialogWidget.this.jcomp)
-								TabOverviewDialogWidget.this.overviewButton
-										.updateLocation(
-												TabOverviewDialogWidget.this.jcomp,
-												currTabAreaInsets);
-						}
-					});
-				}
-				if ("componentOrientation".equals(evt.getPropertyName())) {
+				if ("tabPlacement".equals(evt.getPropertyName())
+						|| "componentOrientation".equals(evt.getPropertyName())
+						|| "tabAreaInsets".equals(evt.getPropertyName())) {
 					SwingUtilities.invokeLater(new Runnable() {
 						public void run() {
 							if (TabOverviewDialogWidget.this.overviewButton
@@ -185,6 +181,30 @@ public class TabOverviewDialogWidget extends LafWidgetAdapter<JTabbedPane> {
 			}
 		};
 		this.jcomp.addPropertyChangeListener(this.propertyListener);
+
+		this.containerListener = new ContainerAdapter() {
+			@Override
+			public void componentAdded(ContainerEvent e) {
+				syncOverviewButtonVisibility();
+			}
+
+			@Override
+			public void componentRemoved(ContainerEvent e) {
+				syncOverviewButtonVisibility();
+			}
+
+			/**
+			 * Syncs the visibility of the tab overview button.
+			 */
+			private void syncOverviewButtonVisibility() {
+				if (overviewButton.getParent() != jcomp)
+					return;
+				// fix for issue 12 - hide the overview button when
+				// there are no tabs
+				overviewButton.setVisible(jcomp.getTabCount() > 0);
+			}
+		};
+		this.jcomp.addContainerListener(this.containerListener);
 	}
 
 	/*
@@ -196,6 +216,9 @@ public class TabOverviewDialogWidget extends LafWidgetAdapter<JTabbedPane> {
 	public void uninstallListeners() {
 		this.jcomp.removePropertyChangeListener(this.propertyListener);
 		this.propertyListener = null;
+
+		this.jcomp.removeContainerListener(this.containerListener);
+		this.containerListener = null;
 	}
 
 	/*
