@@ -31,7 +31,7 @@ package org.jvnet.lafwidget.text;
 
 import java.awt.event.*;
 
-import javax.swing.SwingUtilities;
+import javax.swing.*;
 import javax.swing.text.JTextComponent;
 
 import org.jvnet.lafwidget.LafWidgetAdapter;
@@ -58,6 +58,54 @@ public class SelectOnEscapeWidget extends LafWidgetAdapter<JTextComponent> {
 		return false;
 	}
 
+	@Override
+	public void installUI() {
+		super.installUI();
+
+		InputMap currMap = SwingUtilities.getUIInputMap(this.jcomp,
+				JComponent.WHEN_FOCUSED);
+
+		InputMap newMap = new InputMap();
+		if (currMap != null) {
+			KeyStroke[] kss = currMap.allKeys();
+			for (int i = 0; i < kss.length; i++) {
+				KeyStroke stroke = kss[i];
+				Object val = currMap.get(stroke);
+				newMap.put(stroke, val);
+			}
+		}
+
+		newMap.put(KeyStroke.getKeyStroke(KeyEvent.VK_ESCAPE, 0),
+				"flipTextSelection");
+
+		this.jcomp.getActionMap().put("flipTextSelection",
+				new AbstractAction() {
+					public void actionPerformed(ActionEvent e) {
+						if (LafWidgetUtilities
+								.hasTextFlipSelectOnEscapeProperty(jcomp)) {
+							SwingUtilities.invokeLater(new Runnable() {
+								public void run() {
+									int selectionLength = jcomp
+											.getSelectionEnd()
+											- jcomp.getSelectionStart();
+									if (selectionLength == 0) {
+										jcomp.selectAll();
+									} else {
+										int lastPos = jcomp.getSelectionEnd();
+										jcomp.setSelectionStart(0);
+										jcomp.setSelectionEnd(0);
+										jcomp.setCaretPosition(lastPos);
+									}
+								}
+							});
+						}
+					}
+				});
+
+		SwingUtilities.replaceUIInputMap(this.jcomp, JComponent.WHEN_FOCUSED,
+				newMap);
+	}
+
 	/*
 	 * (non-Javadoc)
 	 * 
@@ -91,7 +139,7 @@ public class SelectOnEscapeWidget extends LafWidgetAdapter<JTextComponent> {
 				}
 			}
 		};
-		this.jcomp.addKeyListener(this.keyListener);
+		// this.jcomp.addKeyListener(this.keyListener);
 	}
 
 	/*
