@@ -59,7 +59,7 @@ public class TestUI extends BasicButtonUI {
 		// AlphaComposite.SRC_OVER, ((Float) alpha).floatValue()));
 		// }
 
-		Map oldRenderingHints = RenderingUtils.installDesktopHints(graphics);
+		Map oldRenderingHints = RenderingUtils.installDesktopHints(graphics, c);
 
 		this.__update(graphics, c);
 		graphics.setComposite(old);
